| dbc2dbf | R Documentation |
Calls the C streaming engine to decompress a .dbc file into a
standard .dbf file without loading the full payload into RAM.
The compressed payload is processed in 64 KB chunks using the PKWare
Implode algorithm (blast.c, Mark Adler).
dbc2dbf(input_file, output_file)
input_file |
Character string. Path to the source |
output_file |
Character string. Path for the output |
TRUE invisibly on success. On failure, stops with a
descriptive error message.
dbc_to_csv, dbc_inspect
dbc <- system.file("extdata", "sids.dbc", package = "dbcturbo")
dbf <- tempfile(fileext = ".dbf")
dbc2dbf(dbc, dbf)
file.exists(dbf)
unlink(dbf)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.