| dbcturbo-package | R Documentation |
A modern, memory-efficient R package for reading and converting DBC files produced by the Brazilian Ministry of Health's 'DATASUS' system. DBC files are DBF databases compressed with the 'PKWare' implode algorithm. Unlike 'read.dbc', this package processes files in streaming mode, never loading the full dataset into RAM. It can export directly to CSV or DBF and provides R helpers for in-memory reading and Parquet conversion.
Maintainer: Gumercindo Pimentel Peralta gumercindopimentel@gmail.com (ORCID)
Authors:
Gumercindo Pimentel Peralta gumercindopimentel@gmail.com (ORCID)
Other contributors:
Juliana da Silva (ORCID) [thesis advisor]
Mark Adler (Author of blast.c (PKWare implode decompressor)) [contributor]
Daniela Petruzalek (Author of read.dbc, dbc2dbf.c) [contributor]
Pablo Fonseca (Author of blast-dbf) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.